@@ -13,10 +13,12 @@
 #' # difficulty levels in the GHAP lexicon
 #' get_tau(items = c("ddifmd001", "DDigmd052", "xyz"))
 #' @export
-get_tau <- function(items,
-                    key = NULL,
-                    itembank = dscore::builtin_itembank,
-                    verbose = FALSE) {
+get_tau <- function(
+  items,
+  key = NULL,
+  itembank = dscore::builtin_itembank,
+  verbose = FALSE
+) {
   key <- set_default_key(key)
 
   if (verbose) {
