@@ -18,8 +18,10 @@ set_default_population <- function(population, idx) {
 
 set_default_transform <- function(transform, idx) {
   if (is.null(transform) && length(idx)) {
-    return(c(dscore::builtin_keys$intercept[idx],
-             dscore::builtin_keys$slope[idx]))
+    return(c(
+      dscore::builtin_keys$intercept[idx],
+      dscore::builtin_keys$slope[idx]
+    ))
   }
   if (is.null(transform) && !length(idx)) {
     return(c(54.939147, 4.064264))
@@ -29,13 +31,14 @@ set_default_transform <- function(transform, idx) {
 
 set_default_qp <- function(qp, idx) {
   if (is.null(qp) && length(idx)) {
-    return(seq(from = dscore::builtin_keys$from[idx],
-               to = dscore::builtin_keys$to[idx],
-               by = dscore::builtin_keys$by[idx]))
+    return(seq(
+      from = dscore::builtin_keys$from[idx],
+      to = dscore::builtin_keys$to[idx],
+      by = dscore::builtin_keys$by[idx]
+    ))
   }
   if (is.null(qp) && !length(idx)) {
     return(-10:100)
   }
   return(qp)
 }
-
