@@ -12,7 +12,18 @@ expect_silent(dscore(data, items = character(0)))
 
 # explicit key "gsed2212"
 expected_d <- c(NA, NA, 6.61, 5.60, 9.09, 9.09, 9.09, 9.09, 15.30, 15.30)
-expected_daz <- c(NA, NA, -2.019, -2.235, -1.447, -1.447, -1.447, -1.447, 0.277, 0.277)
+expected_daz <- c(
+  NA,
+  NA,
+  -2.019,
+  -2.235,
+  -1.447,
+  -1.447,
+  -1.447,
+  -1.447,
+  0.277,
+  0.277
+)
 z <- dscore(data, key = "gsed2212", algorithm = "1.8.7")
 test_that("produces expected D-scores - key gsed2212", {
   expect_identical(z$d, expected_d)
@@ -21,8 +32,16 @@ test_that("produces expected D-scores - key gsed2212", {
 
 z1 <- dscore(data, key = "dutch", algorithm = "1.8.7")
 expected_d1 <- c(
-  NA, -1.87, -1.94, 1.26, 1.26, 1.26, 4.63, 4.63,
-  4.63, 12.06
+  NA,
+  -1.87,
+  -1.94,
+  1.26,
+  1.26,
+  1.26,
+  4.63,
+  4.63,
+  4.63,
+  12.06
 )
 test_that("produces expected D-scores - key dutch", {
   expect_identical(z1$d, expected_d1)
@@ -30,8 +49,16 @@ test_that("produces expected D-scores - key dutch", {
 
 z2 <- dscore(data, key = "gcdg", algorithm = "1.8.7")
 expected_d2 <- c(
-  NA, NA, 3.47, 0.96, 4.83, 4.83, 4.83, 4.83,
-  11.81, 11.81
+  NA,
+  NA,
+  3.47,
+  0.96,
+  4.83,
+  4.83,
+  4.83,
+  4.83,
+  11.81,
+  11.81
 )
 test_that("produces expected D-scores - key gcdg", {
   expect_identical(z2$d, expected_d2)
@@ -47,17 +74,26 @@ test_that("produces expected D-scores - key dutch", {
 
 z5 <- dscore(data, items = items[1:2], key = "dutch", algorithm = "1.8.7")
 expected_d5 <- c(
-  NA, NA, 3.53, 0.59, 4.61, 4.61, 4.61, 4.61,
-  12.06, 12.06
+  NA,
+  NA,
+  3.53,
+  0.59,
+  4.61,
+  4.61,
+  4.61,
+  4.61,
+  12.06,
+  12.06
 )
 test_that("produces expected D-scores - key dutch", {
   expect_identical(z5$d, expected_d5)
 })
 
 test_that("Silently handles outside item code", {
-  expect_silent(dscore(data,
-                       items = c(items[1:2], "gpagmc013"),
-                       algorithm = "1.8.7"
+  expect_silent(dscore(
+    data,
+    items = c(items[1:2], "gpagmc013"),
+    algorithm = "1.8.7"
   ))
 })
 
@@ -104,17 +140,29 @@ qp <- -10:100
 
 algorithm <- "1.8.7"
 algorithm <- "current"
-zd <- dscore(data,
-             items = items, dec = 4, metric = "dscore",
-             itembank = my_itembank, transform = transform, qp = qp,
-             key = "mykey", population = "dutch",
-             algorithm = algorithm,
-             verbose = TRUE
+zd <- dscore(
+  data,
+  items = items,
+  dec = 4,
+  metric = "dscore",
+  itembank = my_itembank,
+  transform = transform,
+  qp = qp,
+  key = "mykey",
+  population = "dutch",
+  algorithm = algorithm,
+  verbose = TRUE
 )
-zl <- dscore(data,
-             items = items, dec = 4, metric = "logit",
-             itembank = my_itembank, key = "mykey", transform = transform, qp = qp,
-             algorithm = algorithm
+zl <- dscore(
+  data,
+  items = items,
+  dec = 4,
+  metric = "logit",
+  itembank = my_itembank,
+  key = "mykey",
+  transform = transform,
+  qp = qp,
+  algorithm = algorithm
 )
 
 lastkey <- builtin_keys[nrow(builtin_keys), ]
@@ -147,47 +195,102 @@ test_that("D-score difference at uneven rows (with start 0) is higher than on un
 })
 
 test_that("get_mu() handles missing ages", {
-  expect_silent(get_mu(t = c(NA, NA),
-                       key = "gsed2406",
-                       prior_mean_NA = 50))
-  expect_silent(get_mu(t = c(NA, -3, 1:3, NA),
-                       key = "gsed2406",
-                       prior_mean_NA = 50))
+  expect_silent(get_mu(t = c(NA, NA), key = "gsed2406", prior_mean_NA = 50))
+  expect_silent(get_mu(
+    t = c(NA, -3, 1:3, NA),
+    key = "gsed2406",
+    prior_mean_NA = 50
+  ))
 })
 
 
 # test empty score vector
 scores <- structure(
   list(
-    age = 0, ddifmd001 = NA_integer_, ddifmd002 = NA_real_,
-    ddifmd003 = NA_real_, ddifmm004 = NA_integer_, ddifmd005 = NA_integer_,
-    ddigmd006 = NA_real_, ddifmd007 = NA_integer_, ddifmd008 = NA_integer_,
-    ddifmm009 = NA_real_, ddifmd010 = NA_real_, ddifmd011 = NA_real_,
-    ddifmm012 = NA_integer_, ddifmd013 = NA_real_, ddifmm014 = NA_integer_,
-    ddifmd015 = NA_real_, ddifmm016 = NA_integer_, ddifmd017 = NA_integer_,
-    ddifmd018 = NA_integer_, ddifmm019 = NA_integer_, ddifmd020 = NA_integer_,
-    ddifmd021 = NA_integer_, ddifmd022 = NA_integer_, ddifmd023 = NA_integer_,
-    ddifmd024 = NA_integer_, ddifmm025 = NA_integer_, ddifmd026 = NA_integer_,
-    ddifmd027 = NA_integer_, ddifmd028 = NA_integer_, ddicmm029 = NA_integer_,
-    ddicmm030 = NA_integer_, ddicmm031 = NA_integer_, ddicmm032 = NA_integer_,
-    ddicmm033 = NA_integer_, ddicmm034 = NA_integer_, ddicmm035 = NA_integer_,
-    ddicmm036 = NA_integer_, ddicmm037 = NA_integer_, ddicmm038 = NA_integer_,
-    ddicmm039 = NA_integer_, ddicmm040 = NA_integer_, ddicmm041 = NA_integer_,
-    ddicmm042 = NA_integer_, ddicmm043 = NA_integer_, ddicmd044 = NA_integer_,
-    ddicmm045 = NA_integer_, ddicmm046 = NA_integer_, ddicmm047 = NA_integer_,
-    ddicmm048 = NA_integer_, ddicmd049 = NA_integer_, ddicmm050 = NA_integer_,
-    ddicmm051 = NA_integer_, ddigmd052 = NA_real_, ddigmd053 = NA_real_,
-    ddigmd054 = NA_integer_, ddigmd155 = NA_real_, ddigmd255 = NA_real_,
-    ddigmd355 = NA_real_, ddigmd055 = NA_real_, ddigmd056 = NA_integer_,
-    ddigmd057 = NA_integer_, ddigmd058 = NA_integer_, ddigmd059 = NA_real_,
-    ddigmm060 = NA_integer_, ddigmd061 = NA_integer_, ddigmd062 = NA_integer_,
-    ddigmd063 = NA_integer_, ddigmm064 = NA_integer_, ddigmm065 = NA_integer_,
-    ddigmm066 = NA_integer_, ddigmm067 = NA_integer_, ddigmd068 = NA_real_,
-    ddigmd168 = NA_real_, ddigmd268 = NA_real_, ddigmd069 = NA_integer_,
-    ddigmd070 = NA_integer_, ddigmd071 = NA_real_, ddigmd072 = NA_integer_,
-    ddigmm073 = NA_integer_, ddigmd074 = NA_integer_, ddigmd075 = NA_real_
+    age = 0,
+    ddifmd001 = NA_integer_,
+    ddifmd002 = NA_real_,
+    ddifmd003 = NA_real_,
+    ddifmm004 = NA_integer_,
+    ddifmd005 = NA_integer_,
+    ddigmd006 = NA_real_,
+    ddifmd007 = NA_integer_,
+    ddifmd008 = NA_integer_,
+    ddifmm009 = NA_real_,
+    ddifmd010 = NA_real_,
+    ddifmd011 = NA_real_,
+    ddifmm012 = NA_integer_,
+    ddifmd013 = NA_real_,
+    ddifmm014 = NA_integer_,
+    ddifmd015 = NA_real_,
+    ddifmm016 = NA_integer_,
+    ddifmd017 = NA_integer_,
+    ddifmd018 = NA_integer_,
+    ddifmm019 = NA_integer_,
+    ddifmd020 = NA_integer_,
+    ddifmd021 = NA_integer_,
+    ddifmd022 = NA_integer_,
+    ddifmd023 = NA_integer_,
+    ddifmd024 = NA_integer_,
+    ddifmm025 = NA_integer_,
+    ddifmd026 = NA_integer_,
+    ddifmd027 = NA_integer_,
+    ddifmd028 = NA_integer_,
+    ddicmm029 = NA_integer_,
+    ddicmm030 = NA_integer_,
+    ddicmm031 = NA_integer_,
+    ddicmm032 = NA_integer_,
+    ddicmm033 = NA_integer_,
+    ddicmm034 = NA_integer_,
+    ddicmm035 = NA_integer_,
+    ddicmm036 = NA_integer_,
+    ddicmm037 = NA_integer_,
+    ddicmm038 = NA_integer_,
+    ddicmm039 = NA_integer_,
+    ddicmm040 = NA_integer_,
+    ddicmm041 = NA_integer_,
+    ddicmm042 = NA_integer_,
+    ddicmm043 = NA_integer_,
+    ddicmd044 = NA_integer_,
+    ddicmm045 = NA_integer_,
+    ddicmm046 = NA_integer_,
+    ddicmm047 = NA_integer_,
+    ddicmm048 = NA_integer_,
+    ddicmd049 = NA_integer_,
+    ddicmm050 = NA_integer_,
+    ddicmm051 = NA_integer_,
+    ddigmd052 = NA_real_,
+    ddigmd053 = NA_real_,
+    ddigmd054 = NA_integer_,
+    ddigmd155 = NA_real_,
+    ddigmd255 = NA_real_,
+    ddigmd355 = NA_real_,
+    ddigmd055 = NA_real_,
+    ddigmd056 = NA_integer_,
+    ddigmd057 = NA_integer_,
+    ddigmd058 = NA_integer_,
+    ddigmd059 = NA_real_,
+    ddigmm060 = NA_integer_,
+    ddigmd061 = NA_integer_,
+    ddigmd062 = NA_integer_,
+    ddigmd063 = NA_integer_,
+    ddigmm064 = NA_integer_,
+    ddigmm065 = NA_integer_,
+    ddigmm066 = NA_integer_,
+    ddigmm067 = NA_integer_,
+    ddigmd068 = NA_real_,
+    ddigmd168 = NA_real_,
+    ddigmd268 = NA_real_,
+    ddigmd069 = NA_integer_,
+    ddigmd070 = NA_integer_,
+    ddigmd071 = NA_real_,
+    ddigmd072 = NA_integer_,
+    ddigmm073 = NA_integer_,
+    ddigmd074 = NA_integer_,
+    ddigmd075 = NA_real_
   ),
-  class = "data.frame", row.names = c(NA, -1L)
+  class = "data.frame",
+  row.names = c(NA, -1L)
 )
 
 test_that("empty vector works with all keys", {
@@ -210,7 +313,10 @@ test_that("prepend attaches two ID columns", {
   expect_equal(ncol(dscore(data2, prepend = c("id_chr", "id_num"))), 2 + 6)
 })
 test_that("unknown variables names produce notfound warning", {
-  expect_warning(dscore(data2, prepend = c("idonotexist")), "Not found: idonotexist")
+  expect_warning(
+    dscore(data2, prepend = c("idonotexist")),
+    "Not found: idonotexist"
+  )
 })
 test_that("reserved names produce overwrite warning", {
   expect_warning(dscore(data2, prepend = c("a", "d")))
